@@ -336,13 +336,7 @@ class ApiClient:
     def _call(self, name_parts: Sequence[str], params: dict, json=None):
         """ Construct the call """
         verb, path, params = self._get_verb_path_params(name_parts, params)
-        if verb in {"POST", "DELETE", "PUT", "PATCH"} and json is None:
-            headers = {"Content-Length": "0"}
-        else:
-            headers = None
-        resp = self.session.request(
-            verb, path, params=params, json=json, headers=headers
-        )
+        resp = self.session.request(verb, path, params=params, json=json)
         resp.raise_for_status()
         if not resp.content:
             return None
